==> haskell-aeson-pretty-0.8.5-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.8.5
id: aeson-pretty-0.8.5-H1b2eM8YDbuBUbo3hCSZT4
key: aeson-pretty-0.8.5-H1b2eM8YDbuBUbo3hCSZT4
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.Encode.Pretty
abi: 9056a38eee22497a3d57d29a8fbba3fe
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/aeson-pretty-0.8.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/aeson-pretty-0.8.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/aeson-pretty-0.8.5
hs-libraries: HSaeson-pretty-0.8.5-H1b2eM8YDbuBUbo3hCSZT4
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0
    base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW bytestring-0.10.8.2
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.8.5-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.8.5
id: aeson-pretty-0.8.5-9BxbFsM21RbE8Yp2sqULuj
key: aeson-pretty-0.8.5-9BxbFsM21RbE8Yp2sqULuj
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.Encode.Pretty
abi: b651a847597536fb9052cd576ccf3e1b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/aeson-pretty-0.8.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/aeson-pretty-0.8.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/aeson-pretty-0.8.5
hs-libraries: HSaeson-pretty-0.8.5-9BxbFsM21RbE8Yp2sqULuj
depends:
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq base-4.10.0.0
    base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW bytestring-0.10.8.2
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
